@@ -159,6 +159,21 @@ class SnakeGame :
                             self.game_over=True
                             get_gameovere_bar(self.__score, self.grid_size[0])
                             break
+                        elif self.last_keys[0]==0 :
+                            for index, item in enumerate (self.snake_body ):
+                                if index==0 :
+                                    head=self.snake_body[0]
+                                    self.snake_body[index]=(item[0], item[1]-1)
+                                    self.snake_body.insert(1, head)
+                                    self.snake_body.pop()
+                        elif self.last_keys[0]==1 :
+                            for index, item in enumerate (self.snake_body ):
+                                if index==0 :
+                                    head=self.snake_body[0]
+                                    self.snake_body[index]=(item[0]-1, item[1])
+                                    self.snake_body.insert(1, head)
+                                    self.snake_body.pop()
+
                     elif len(self.last_keys) > 1 :
                         head=self.snake_body[0]
                         if self.last_keys.count(self.last_keys[0]) >1 :
@@ -193,6 +208,7 @@ class SnakeGame :
 
                     elif self.food ==self.snake_body[0] :
                         self.__score+=1
+
                         self.food=random.choice(self.board)
                         self.snake_body.append(self.snake_body[-1])
 
@@ -284,7 +300,6 @@ class SnakeGame :
                 while (not self.game_over):
                     if isData():
                         c = sys.stdin.read(1)
-                        # custom_print (str(c))
                         if c == '\x1b':  # start of escape sequence
                             c += sys.stdin.read(2)
                         if self.game_paused :
